@@ -115,6 +115,7 @@ impl<'a> ExecuteWebhook<'a> {
     /// Attach a file to the webhook.
     ///
     /// This method is repeatable.
+    #[deprecated(since = "0.5.5", note = "will be removed in favor of `files`")]
     pub fn file(mut self, name: impl Into<String>, file: impl Into<Vec<u8>>) -> Self {
         self.files.push((name.into(), file.into()));
 
@@ -124,11 +125,13 @@ impl<'a> ExecuteWebhook<'a> {
     /// Attach multiple files to the webhook.
     pub fn files<N: Into<String>, F: Into<Vec<u8>>>(
         mut self,
-        attachments: impl IntoIterator<Item = (N, F)>,
+        files: impl IntoIterator<Item = (N, F)>,
     ) -> Self {
-        for (name, file) in attachments {
-            self = self.file(name, file);
-        }
+        self.files.extend(
+            files
+                .into_iter()
+                .map(|(name, file)| (name.into(), file.into())),
+        );
 
         self
     }
