@@ -1,7 +1,7 @@
 use crate::{
     client::Client,
     error::Error,
-    request::{self, AuditLogReason, AuditLogReasonError, Pending, Request},
+    request::{self, AuditLogReason, AuditLogReasonError, NullableField, Pending, Request},
     routing::Route,
 };
 use serde::Serialize;
@@ -12,15 +12,12 @@ use twilight_model::{
 
 #[derive(Default, Serialize)]
 struct UpdateWebhookFields {
-    #[allow(clippy::option_option)]
     #[serde(skip_serializing_if = "Option::is_none")]
-    avatar: Option<Option<String>>,
-    #[allow(clippy::option_option)]
+    avatar: Option<NullableField<String>>,
     #[serde(skip_serializing_if = "Option::is_none")]
     channel_id: Option<ChannelId>,
-    #[allow(clippy::option_option)]
     #[serde(skip_serializing_if = "Option::is_none")]
-    name: Option<Option<String>>,
+    name: Option<NullableField<String>>,
 }
 
 /// Update a webhook by ID.
@@ -52,7 +49,9 @@ impl<'a> UpdateWebhook<'a> {
     ///
     /// [Discord Docs/Image Data]: https://discord.com/developers/docs/reference#image-data
     pub fn avatar(mut self, avatar: impl Into<Option<String>>) -> Self {
-        self.fields.avatar.replace(avatar.into());
+        self.fields
+            .avatar
+            .replace(NullableField::from_option(avatar.into()));
 
         self
     }
@@ -66,7 +65,9 @@ impl<'a> UpdateWebhook<'a> {
 
     /// Change the name of the webhook.
     pub fn name(mut self, name: impl Into<Option<String>>) -> Self {
-        self.fields.name.replace(name.into());
+        self.fields
+            .name
+            .replace(NullableField::from_option(name.into()));
 
         self
     }
