@@ -1,4 +1,10 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error as HttpError,
+    request::{validate, Pending, Request},
+    routing::Route,
+};
+use serde::Serialize;
 use std::{
     error::Error,
     fmt::{Display, Formatter, Result as FmtResult},
@@ -101,8 +107,6 @@ struct CreateGuildFields {
     icon: Option<String>,
     name: String,
     #[serde(skip_serializing_if = "Option::is_none")]
-    region: Option<String>,
-    #[serde(skip_serializing_if = "Option::is_none")]
     roles: Option<Vec<RoleFields>>,
     #[serde(skip_serializing_if = "Option::is_none")]
     system_channel_id: Option<ChannelId>,
@@ -259,7 +263,6 @@ impl<'a> CreateGuild<'a> {
                 explicit_content_filter: None,
                 icon: None,
                 name,
-                region: None,
                 roles: None,
                 system_channel_id: None,
                 system_channel_flags: None,
@@ -413,16 +416,6 @@ impl<'a> CreateGuild<'a> {
         self
     }
 
-    /// Specify the voice server region for the guild. Refer to [the discord docs] for more
-    /// information.
-    ///
-    /// [the discord docs]: https://discord.com/developers/docs/resources/voice#voice-region-object
-    pub fn region(mut self, region: impl Into<String>) -> Self {
-        self.fields.region.replace(region.into());
-
-        self
-    }
-
     /// Set the channel where system messages will be posted.
     ///
     /// This must be an ID specified in [`channels`].
@@ -482,7 +475,7 @@ impl<'a> CreateGuild<'a> {
         Ok(self)
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), HttpError> {
         let request = Request::builder(Route::CreateGuild)
             .json(&self.fields)?
             .build();
