@@ -1,4 +1,9 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error,
+    request::{Pending, Request},
+    routing::Route,
+};
 use twilight_model::{channel::Webhook, id::GuildId};
 
 /// Get the webhooks of a guild.
@@ -17,7 +22,7 @@ impl<'a> GetGuildWebhooks<'a> {
         }
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), Error> {
         let request = Request::from_route(Route::GetGuildWebhooks {
             guild_id: self.guild_id.0,
         });
