@@ -1,13 +1,67 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error as HttpError,
+    request::{validate, Pending, Request},
+    routing::Route,
+};
+use serde::Serialize;
 use std::{
     error::Error,
     fmt::{Display, Formatter, Result as FmtResult},
 };
 use twilight_model::{id::GuildId, template::Template};
 
-#[derive(Clone, Debug)]
+/// Error emitted when the template can not be upated as configured.
+#[derive(Debug)]
+pub struct UpdateTemplateError {
+    kind: UpdateTemplateErrorType,
+}
+
+impl UpdateTemplateError {
+    /// Immutable reference to the type of error that occurred.
+    #[must_use = "retrieving the type has no effect if left unused"]
+    pub const fn kind(&self) -> &UpdateTemplateErrorType {
+        &self.kind
+    }
+
+    /// Consumes the error, returning the source error if there is any.
+    #[allow(clippy::unused_self)]
+    #[must_use = "consuming the error and retrieving the source has no effect if left unused"]
+    pub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>> {
+        None
+    }
+
+    /// Consume the error, returning the owned error type nad the source error.
+    #[must_use = "consuming the error int its parts has no effect if left unused"]
+    pub fn into_parts(
+        self,
+    ) -> (
+        UpdateTemplateErrorType,
+        Option<Box<dyn Error + Send + Sync>>,
+    ) {
+        (self.kind, None)
+    }
+}
+
+impl Display for UpdateTemplateError {
+    fn fmt(&self, f: &mut Formatter<'_>) -> FmtResult {
+        match self.kind {
+            UpdateTemplateErrorType::NameInvalid { .. } => {
+                f.write_str("the template name is invalid")
+            }
+            UpdateTemplateErrorType::DescriptionTooLarge { .. } => {
+                f.write_str("the template description is too large")
+            }
+        }
+    }
+}
+
+impl Error for UpdateTemplateError {}
+
+/// Type of [`UpdateTemplateError`] that occurred.
+#[derive(Debug)]
 #[non_exhaustive]
-pub enum UpdateTemplateError {
+pub enum UpdateTemplateErrorType {
     /// Name of the template is invalid.
     NameInvalid {
         /// Provided name.
@@ -20,19 +74,6 @@ pub enum UpdateTemplateError {
     },
 }
 
-impl Display for UpdateTemplateError {
-    fn fmt(&self, f: &mut Formatter<'_>) -> FmtResult {
-        match self {
-            Self::NameInvalid { .. } => f.write_str("the template name is invalid"),
-            Self::DescriptionTooLarge { .. } => {
-                f.write_str("the template description is too large")
-            }
-        }
-    }
-}
-
-impl Error for UpdateTemplateError {}
-
 #[derive(Serialize)]
 struct UpdateTemplateFields {
     name: Option<String>,
@@ -76,15 +117,17 @@ impl<'a> UpdateTemplate<'a> {
     ///
     /// # Errors
     ///
-    /// Returns [`UpdateTemplateError::DescriptionTooLarge`] when the
-    /// description is too large.
+    /// Returns an [`UpdateTemplateErrorType::DescriptionTooLarge`] error type
+    /// if the description is too large.
     pub fn description(self, description: impl Into<String>) -> Result<Self, UpdateTemplateError> {
         self._description(description.into())
     }
 
     fn _description(mut self, description: String) -> Result<Self, UpdateTemplateError> {
         if !validate::template_description(&description) {
-            return Err(UpdateTemplateError::DescriptionTooLarge { description });
+            return Err(UpdateTemplateError {
+                kind: UpdateTemplateErrorType::DescriptionTooLarge { description },
+            });
         }
 
         self.fields.description.replace(description);
@@ -98,14 +141,17 @@ impl<'a> UpdateTemplate<'a> {
     ///
     /// # Errors
     ///
-    /// Returns [`UpdateTemplateError::NameInvalid`] when the name is invalid.
+    /// Returns an [`UpdateTemplateErrorType::NameInvalid`] error type if the
+    /// name is invalid.
     pub fn name(self, name: impl Into<String>) -> Result<Self, UpdateTemplateError> {
         self._name(name.into())
     }
 
     fn _name(mut self, name: String) -> Result<Self, UpdateTemplateError> {
         if !validate::template_name(&name) {
-            return Err(UpdateTemplateError::NameInvalid { name });
+            return Err(UpdateTemplateError {
+                kind: UpdateTemplateErrorType::NameInvalid { name },
+            });
         }
 
         self.fields.name.replace(name);
@@ -113,7 +159,7 @@ impl<'a> UpdateTemplate<'a> {
         Ok(self)
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), HttpError> {
         let request = Request::builder(Route::UpdateTemplate {
             guild_id: self.guild_id.0,
             template_code: self.template_code.clone(),
